@@ -312,6 +312,13 @@ class CpanelBackupImporter {
         foreach (glob($userdataDir . "/*") as $file) {
             if (is_file($file)) {
                 $domain = basename($file);
+                
+                // Skip _SSL domains as they are just SSL tracking entries in cPanel
+                if (strpos($domain, '_SSL') !== false) {
+                    $this->log("Skipping SSL tracking domain: " . $domain, 'info');
+                    continue;
+                }
+                
                 $config = $this->parseUserdataFile($file);
                 if ($config) {
                     $domains[$domain] = $config;
@@ -753,10 +760,21 @@ class CpanelBackupImporter {
     }
     
     /**
-     * Import MySQL users
+     * Import MySQL users (deduplicated)
      */
     private function importMysqlUsers($backupData) {
+        $uniqueUsers = [];
+        
+        // Deduplicate users from grants
         foreach ($backupData['mysql_grants'] as $grant) {
+            $originalUser = $grant['username'];
+            if (!isset($uniqueUsers[$originalUser])) {
+                $uniqueUsers[$originalUser] = $grant;
+            }
+        }
+        
+        // Create each unique user once
+        foreach ($uniqueUsers as $grant) {
             $this->createMysqlUser($grant);
         }
     }
@@ -825,51 +843,20 @@ class CpanelBackupImporter {
     }
     
     /**
-     * Create DNS records for a specific domain using PowerDNS
+     * Create DNS records for a specific domain using PowerDNS integration
      */
     private function createDomainDnsRecords($domain) {
         try {
-            // Check if domain zone exists
-            $zoneExists = false;
-            $zones = $this->powerDNS->getZones();
-            foreach ($zones as $zone) {
-                if ($zone['name'] === $domain . '.') {
-                    $zoneExists = true;
-                    break;
-                }
-            }
-            
-            if (!$zoneExists) {
-                // Create zone
-                $result = $this->powerDNS->createZone($domain, $this->username);
-                if ($result) {
-                    $this->log("DNS zone created for: $domain");
-                } else {
-                    $this->log("Failed to create DNS zone for: $domain", 'warning');
-                    return;
-                }
-            }
-            
-            // Get server IP
-            $serverIp = $this->getServerIp();
-            if (!$serverIp) {
-                $this->log("Could not determine server IP - skipping DNS records for: $domain", 'warning');
-                return;
-            }
-            
-            // Add A records pointing to server IP
-            try {
-                $this->powerDNS->addRecord($domain, $domain, 'A', $serverIp, 300);
-                $this->log("Created DNS A record: $domain -> $serverIp");
-                
-                $this->powerDNS->addRecord($domain, 'www.' . $domain, 'A', $serverIp, 300);
-                $this->log("Created DNS A record: www.$domain -> $serverIp");
-            } catch (Exception $e) {
-                $this->log("Failed to create DNS A records for $domain: " . $e->getMessage(), 'warning');
+            // Create zone using PowerDNS integration (same as domains.php)
+            $result = $this->powerDNS->createZoneForDomain($domain, $this->username);
+            if ($result['success']) {
+                $this->log("DNS zone created for: $domain");
+            } else {
+                $this->log("DNS zone creation failed for: $domain - " . ($result['error'] ?? 'Unknown error'), 'warning');
             }
             
         } catch (Exception $e) {
-            $this->log("Failed to create DNS records for " . $domain . ": " . $e->getMessage(), 'error');
+            $this->log("Failed to create DNS records for " . $domain . ": " . $e->getMessage(), 'warning');
         }
     }
     
